Usage
bcl(r,b,gam,xdat,ydat,id,tvec,margmodel,corstr,link)
bcl.ord(r,b,gam,xdat,ydat,id,tvec,corstr,link)
Arguments
r
The vector of normal copula parameters.
b
The regression coefficients.
gam
The uinivariate parameters that are not regression coefficients. That is the parameter $\gamma$ of negative binomial distribution or the $q$-dimensional vector of the univariate cutpoints of ordinal model. $\gamma$ is NULL for Poisson and binary regression.
xdat
$(\mathbf{x}_1 , \mathbf{x}_2 , \ldots , \mathbf{x}_n )^\top$, where
the matrix $\mathbf{x}_i,\,i=1,\ldots,n$ for a given unit will
depend on the times of observation for that unit ($j_i$) and will have
number of rows $j_i$, each row corresponding to one of the $j_i$ elements
of $y_i$ and $p$ columns where $p$ is the number of covariates including
the unit first column to account for the intercept (except for ordinal regression where there is no intercept). This xdat matrix is
of dimension $(N\times p),$ where $N =\sum_{i=1}^n j_i$ is the total
number of observations from all units.
ydat
$(y_1 , y_2 , \ldots , y_n )^\top$, where
the response data vectors $y_i,\,i=1,\ldots,n$
are of possibly different lengths for different units. In particular,
we now have that $y_i$ is ($j_i \times 1$), where $j_i$ is the number of
observations on unit $i$. The total number of observations from all units
is $N =\sum_{i=1}^n j_i$. The ydat are the collection of data vectors
$y_i, i = 1,\ldots,n$ one from each unit which summarize all the data
together in a single, long vector of length $N$.
id
An index for individuals or clusters.
tvec
A vector with the time indicator of individuals or clusters.
margmodel
Indicates the marginal model.
Choices are poisson for Poisson, bernoulli for Bernoulli,
and nb1 , nb2 for the NB1 and NB2 parametrization
of negative binomial in Cameron and Trivedi (1998).
corstr
Indicates the latent correlation structure of normal copula.
Choices are exch, ar, and unstr for exchangeable, ar(1)
and unstructured correlation structure, respectively.
link
The link function.
Choices are log for the log link function, logit for
the logit link function, and probit for
the probit link function.