| weightedScores-package | R Documentation |
The weighted scores method and CL1 information criteria as an intermediate step for variable/correlation selection for longitudinal ordinal and count data in Nikoloulopoulos, Joe and Chaganty (2011) and Nikoloulopoulos (2016, 2020).
This package contains R functions to implement:
The weighted scores method for regression models with dependent data and negative binomial (Nikoloulopoulos, Joe and Chaganty, 2011), GLM (Nikoloulopoulos, 2016) and ordinal probit/logistic (Nikoloulopoulos, 2020) margins.
The composite likelihood information criteria for regression models with dependent data and ordinal probit/logistic margins (Nikoloulopoulos, 2016, 2020).
Aristidis K. Nikoloulopoulos.
Nikoloulopoulos, A.K., Joe, H. and Chaganty, N.R. (2011) Weighted scores method for regression models with dependent data. Biostatistics, 12, 653–665. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/biostatistics/kxr005")}.
Nikoloulopoulos, A.K. (2016) Correlation structure and variable selection in generalized estimating equations via composite likelihood information criteria. Statistics in Medicine, 35, 2377–2390. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/sim.6871")}.
Nikoloulopoulos, A.K. (2020) Weighted scores estimating equations and CL1 information criteria for longitudinal ordinal response. Journal of Statistical Computation and Simulation, 90, 2002–2022. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/00949655.2020.1759602")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.