Learn R Programming

weightedScores (version 0.9.5.1)

wtsc: THE WEIGHTED SCORES EQUATIONS WITH INPUTS OF THE WEIGHT MATRICES AND THE DATA

Description

The weighted scores equations with inputs of the weight matrices and the data.

Usage

wtsc(param,WtScMat,xdat,ydat,id,tvec,margmodel,link)
wtsc.ord(param,WtScMat,xdat,ydat,id,tvec,link)

Arguments

param
The vector of regression and not regression parameters.
WtScMat
A list containing the following components. omega: The array with the $\Omega_i,\,i=1,\ldots,n$ matrices; delta: The array with the $\Delta_i,\,i=1,\ldots,n$ matrices; X: The array with the $X_i,\,i=1,\ldots,n$ matrices.
xdat
$(\mathbf{x}_1 , \mathbf{x}_2 , \ldots , \mathbf{x}_n )^\top$, where the matrix $\mathbf{x}_i,\,i=1,\ldots,n$ for a given unit will depend on the times of observation for that unit ($j_i$) and will have number of rows $j_i$, each row corresponding
ydat
$(y_1 , y_2 , \ldots , y_n )^\top$, where the response data vectors $y_i,\,i=1,\ldots,n$ are of possibly different lengths for different units. In particular, we now have that $y_i$ is ($j_i \times 1$), where $j_i$ is the number of observation
id
An index for individuals or clusters.
tvec
A vector with the time indicator of individuals or clusters.
margmodel
Indicates the marginal model. Choices are poisson for Poisson, bernoulli for Bernoulli, and nb1 , nb2 for the NB1 and NB2 parametrization of negative binomial in Cameron and Triv
link
The link function. Choices are log for the log link function, logit for the logit link function, and probit for the probit link function.

Value

  • The weighted scores equations.

Details

The weighted scores estimating equations, with $W_{i,\rm working}$ based on a working discretized MVN, have the form: $$g_1= g_1( a)=\sum_{i=1}^n X_i^T\, W_{i,{\rm working}}^{-1}\, s_i( a)=0,$$ where $W_{i,\rm working}^{-1}=\Delta_i\Omega_{i,\rm working}^{-1}= \Delta_i({\tilde a})\Omega_i({\tilde a},{\tilde R})^{-1}$ is based on the covariance matrix of $s_i( a)$ computed from the fitted discretized MVN model with estimated parameters ${\tilde a}, {\tilde R}$.

Note that wtsc.ord is a variant of the code for ordinal (probit and logistic) regression.

References

Nikoloulopoulos, A.K., Joe, H. and Chaganty, N.R. (2011) Weighted scores method for regression models with dependent data. Biostatistics, 12, 653--665.

Nikoloulopoulos, A.K. (2015a) Correlation structure and variable selection in generalized estimating equations via composite likelihood information criteria. Arxiv e-prints.

Nikoloulopoulos, A.K. (2015b) Weighted scores estimating equations for longitudinal ordinal data. Arxiv e-prints.

See Also

solvewtsc, weightMat, godambe, wtsc.wrapper