Approximation of bivariate standard normal cumulative distribution function (Johnson and Kotz, 1972).
approxbvncdf(r,x1,x2,x1s,x2s,x1c,x2c,x1f,x2f,t1,t2)An approximation of bivariate normal cumulative distribution function.
The correlation parameter of bivariate standard normal distribution.
\(x_1,\) see details.
\(x_2,\) see details.
\(x_1^2.\)
\(x_2^2.\)
\(x_1^3.\)
\(x_2^3.\)
\(x_1^4.\)
\(x_2^4.\)
\(\Phi(x_1)\Phi(x_2),\) where \(\Phi(\cdot)\) is the cdf of univariate standard normal distribution.
\(\phi(x_1)\phi(x_2),\) where \(\phi(\cdot)\) is the density of univariate stamdard normal distribution.
The approximation for the bivariate normal cdf is from Johnson and Kotz (1972), page 118. Let \(\Phi_2(x_1,x_2;\rho)=Pr(Z_1\le x_1,\,Z_2\le x_2)\), where \((Z_1,Z_2)\) is bivariate normal with means 0, variances 1 and correlation \(\rho\). An expansion, due to Pearson (1901), is $$ \Phi_2(x_1,x_2;\rho) =\Phi(x_1)\Phi(x_2) +\phi(x_1)\phi(x_2) \sum_{j=1}^\infty \rho^j \psi_j(x_1) \psi_j(x_2)/j!$$ where $$\psi_j(z) = (-1)^{j-1} d^{j-1} \phi(z)/dz^{j-1}.$$ Since $$\phi'(z) = -z\phi(z), \phi''(z) = (z^2-1)\phi(z) , \phi'''(z) = [2z-z(z^2-1)]\phi(z) = (3z-z^3)\phi(z) ,$$ $$\phi^{(4)}(z) = [3-3z^2-z(3z-z^3)]\phi(z) = (3-6z^2+z^4)\phi(z)$$ we have $$ \Phi_2(x_1,x_2;\rho) = \Phi(x_1)\Phi(x_2)+\phi(x_1)\phi(x_2) [\rho+ \rho^2x_1x_2/2 + \rho^3 (x_1^2-1)(x_2^2-1)/6 +\rho^4 (x_1^3-3x_1)(x_2^3-3x_2)/24$$ $$+\rho^5 (x_1^4-6x_1^2+3)(x_2^4-6x_2^2+3)/120+\cdots ] $$ A good approximation is obtained truncating the series at \(\rho^3\) term for \(|\rho| \le 0.4\), and at \(\rho^5\) term for \(0.4 < |\rho|\le 0.7\). Higher order terms may be required for \(|\rho| > 0.7\).
Johnson, N. L. and Kotz, S. (1972) Continuous Multivariate Distributions. Wiley, New York.
Pearson, K. (1901) Mathematical contributions to the theory of evolution-VII. On the correlation of characters not quantitatively measureable. Philosophical Transactions of the Royal Society of London, Series A, 195, 1--47.
scoreCov