dmargmodel(y,mu,gam,invgam,margmodel)
pmargmodel(y,mu,gam,invgam,margmodel)
dmargmodel.ord(y,mu,gam,link)
pmargmodel.ord(y,mu,gam,link)Cameron and Trivedi (1998) present the NBk parametrization where $\tau=\mu^{2-k}\gamma^{-1}$ and $\xi=\mu^{k-1}\gamma$, $1\le k\le 2$. In this function we use the NB1 parametrization $(\tau=\mu\gamma^{-1},\; \xi=\gamma)$, and the NB2 parametrization $(\tau=\gamma^{-1},\; \xi=\mu\gamma)$; the latter is the same as in Lawless (1987).
margmodel.ord is a variant of the code for ordinal (probit and logistic) model. In this case, the response $Y$ is assumed to have density
$$f_1(y;\nu,\gamma)=F(\alpha_{y}+\nu)-F(\alpha_{y-1}+\nu),$$
where $\nu=x\beta$ is a function of $x$
and the $p$-dimensional regression vector $\beta$, and $\gamma=(\alpha_1,\ldots,\alpha_{K-1})$ is the $q$-dimensional vector of the univariate cutpoints ($q=K-1$). Note that $F$ normal leads to the probit model and $F$ logistic
leads to the cumulative logit model for ordinal response.
Lawless, J. F. (1987) Negative binomial and mixed Poisson regression. The Canadian Journal of Statistics, 15, 209--225.
Nikoloulopoulos, A.K. (2015b) Weighted scores estimating equations for longitudinal ordinal data. Arxiv e-prints.
y<-3
gam<-2.5
invgam<-1/2.5
mu<-0.5
margmodel<-"nb2"
dmargmodel(y,mu,gam,invgam,margmodel)
pmargmodel(y,mu,gam,invgam,margmodel)
link="probit"
dmargmodel.ord(y,mu,gam,link)
pmargmodel.ord(y,mu,gam,link)Run the code above in your browser using DataLab