The matrix of the score functions with respect to $\nu$.
scgam
The matrix of the score functions with respect to $\gamma$.
pmf
The matrix of rectangle probabilities.
index
The bivariate pair.
margmodel
Indicates the marginal model.
Choices are poisson for Poisson, bernoulli for Bernoulli,
and nb1 , nb2 for the NB1 and NB2 parametrization
of negative binomial in Cameron and Trivedi (1998).
Value
$\Omega_i$.
Details
The covariance matrix $\Omega_i$ of $ s_i(a)$ computed from the
fitted discretized MVN model with estimated parameters ${\tilde a},
{\tilde R}$.
Note that scoreCov.ord is a variant of the code for ordinal (probit and logistic) regression.