Usage
wtsc(param,WtScMat,xdat,ydat,id,tvec,margmodel,link)
wtsc.ord(param,WtScMat,xdat,ydat,id,tvec,link)
Arguments
param
The vector of regression and not regression parameters.
WtScMat
A list containing the following components.
omega: The array with the $\Omega_i,\,i=1,\ldots,n$ matrices;
delta: The array with the $\Delta_i,\,i=1,\ldots,n$ matrices;
X: The array with the $X_i,\,i=1,\ldots,n$ matrices.
xdat
$(\mathbf{x}_1 , \mathbf{x}_2 , \ldots ,
\mathbf{x}_n )^\top$, where the matrix $\mathbf{x}_i,\,i=1,\ldots,n$ for a given unit will
depend on the times of observation for that unit ($j_i$) and will have
number of rows $j_i$, each row corresponding
ydat
$(y_1 , y_2 , \ldots , y_n )^\top$, where
the response data vectors $y_i,\,i=1,\ldots,n$
are of possibly different lengths for different units. In particular,
we now have that $y_i$ is ($j_i \times 1$), where $j_i$ is the number of
observation
id
An index for individuals or clusters.
tvec
A vector with the time indicator of individuals or clusters.
margmodel
Indicates the marginal model.
Choices are poisson for Poisson, bernoulli for Bernoulli,
and nb1 , nb2 for the NB1 and NB2 parametrization
of negative binomial in Cameron and Triv
link
The link function.
Choices are log for the log link function, logit for
the logit link function, and probit for
the probit link function.